"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const tree_1 = require("../utility/tree");
const workspace_1 = require("../utility/workspace");
function addPackageJsonScript() {
    return (tree) => {
        const packageJson = JSON.parse(tree_1.readRequiredFile(tree, '/package.json'));
        packageJson.scripts = packageJson.scripts || {};
        packageJson.scripts['skyux:generate-documentation'] =
            'ng generate @skyux-sdk/documentation-schematics:documentation';
        packageJson.scripts.postbuild = 'npm run skyux:generate-documentation';
        tree.overwrite('/package.json', JSON.stringify(packageJson, undefined, 2));
    };
}
function addDocumentationDirectoryToEslintIgnore(project) {
    return (tree) => {
        const eslintPath = core_1.normalize(`${project.root}/.eslintrc.json`);
        if (tree.exists(eslintPath)) {
            const eslintJson = JSON.parse(tree.read(eslintPath).toString());
            eslintJson.ignorePatterns.push('documentation/**/*');
            tree.overwrite(eslintPath, JSON.stringify(eslintJson, undefined, 2));
        }
    };
}
function ngAdd(options) {
    return (tree) => __awaiter(this, void 0, void 0, function* () {
        const { workspace } = yield workspace_1.getWorkspace(tree);
        const { project } = yield workspace_1.getProject(workspace, options.project || workspace.extensions.defaultProject);
        return schematics_1.chain([
            addPackageJsonScript(),
            addDocumentationDirectoryToEslintIgnore(project),
            (_tree, context) => {
                context.addTask(new tasks_1.NodePackageInstallTask());
            },
        ]);
    });
}
exports.default = ngAdd;
//# sourceMappingURL=ng-add.schematic.js.map