"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProject = exports.getWorkspace = void 0;
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
const tree_1 = require("./tree");
/**
 * Creates a workspace host.
 * Taken from: https://angular.io/guide/schematics-for-libraries#get-the-project-configuration
 */
function createHost(tree) {
    return {
        /* istanbul ignore next */
        readFile(path) {
            return __awaiter(this, void 0, void 0, function* () {
                return tree_1.readRequiredFile(tree, path);
            });
        },
        /* istanbul ignore next */
        writeFile(path, data) {
            return __awaiter(this, void 0, void 0, function* () {
                return tree.overwrite(path, data);
            });
        },
        /* istanbul ignore next */
        isDirectory(path) {
            return __awaiter(this, void 0, void 0, function* () {
                // approximate a directory check
                return !tree.exists(path) && tree.getDir(path).subfiles.length > 0;
            });
        },
        /* istanbul ignore next */
        isFile(path) {
            return __awaiter(this, void 0, void 0, function* () {
                return tree.exists(path);
            });
        },
    };
}
/**
 * Returns the workspace host and project config (angular.json).
 */
function getWorkspace(tree) {
    return __awaiter(this, void 0, void 0, function* () {
        const host = createHost(tree);
        const { workspace } = yield core_1.workspaces.readWorkspace('/', host);
        return { host, workspace };
    });
}
exports.getWorkspace = getWorkspace;
function getProject(workspace, projectName) {
    return __awaiter(this, void 0, void 0, function* () {
        const project = workspace.projects.get(projectName);
        /* istanbul ignore next */
        if (!project) {
            throw new schematics_1.SchematicsException(`The "${projectName}" project is not defined in angular.json. Provide a valid project name.`);
        }
        return { project, projectName };
    });
}
exports.getProject = getProject;
//# sourceMappingURL=workspace.js.map